Learn R Programming

hdsvm (version 1.0.2)

coef.cv.nc.hdsvm: Extract Coefficients from a `cv.nc.hdsvm` Object

Description

Retrieves coefficients at specified values of `lambda` from a fitted `cv.nc.hdsvm()` model. Utilizes the stored `"nchdsvm.fit"` object and the optimal `lambda` values determined during the cross-validation process.

Usage

# S3 method for cv.nc.hdsvm
coef(object, s = c("lambda.1se", "lambda.min"), ...)

Value

Returns a vector or matrix of coefficients corresponding to the specified `lambda` values.

Arguments

object

A fitted `cv.nc.hdsvm()` object from which coefficients are to be extracted.

s

Specifies the `lambda` values at which coefficients are requested. The default is `s = "lambda.1se"`, representing the largest `lambda` such that the cross-validation error estimate is within one standard error of the minimum. Alternatively, `s = "lambda.min"` corresponds to the `lambda` yielding the minimum cross-validation error. If `s` is numeric, these values are directly used as the `lambda` values for coefficient extraction.

...

Not used.

See Also

cv.nc.hdsvm, predict.cv.nc.hdsvm

Examples

Run this code
set.seed(315)
n <- 100
p <- 400
x1 <- matrix(rnorm(n / 2 * p, -0.25, 0.1), n / 2)
x2 <- matrix(rnorm(n / 2 * p, 0.25, 0.1), n / 2)
x <- rbind(x1, x2)
beta <- 0.1 * rnorm(p)
prob <- plogis(c(x %*% beta))
y <- 2 * rbinom(n, 1, prob) - 1
lam2 <- 0.01
lambda <- 10^(seq(1,-4, length.out = 30))
cv.nc.fit <- cv.nc.hdsvm(x = x, y = y, lambda = lambda, lam2 = lam2, pen = "scad")
coef(cv.nc.fit, s = c(0.02, 0.03))

Run the code above in your browser using DataLab